Enum Error
pub enum Error {
Show 13 variants
Io(Error),
Vtkio(Error),
NtoolsUtils(Error),
FailedToParseType {
target: String,
input: String,
},
UnknownMeshFormat {
mesh_id: u32,
format: Format,
},
TallyNotFound {
mesh_id: u32,
},
PointNotFound {
point: Point,
},
EmptyCollection,
IndexOutOfBounds {
minimum: usize,
maximum: usize,
actual: usize,
},
UnexpectedLength {
expected: usize,
found: usize,
},
UnexpectedNumberOfVoxels {
id: u32,
expected: usize,
found: usize,
},
FailedParse {
reason: String,
context: String,
},
Nom(String),
}Expand description
The error type for ntools-mesh
Variants
Io(Error)
Errors from std::io
Vtkio(Error)
Errors from the vtkio crate
NtoolsUtils(Error)
Errors from ntools utilities
FailedToParseType
Unable to create a target type from input
UnknownMeshFormat
Unable to detect the mesh type from the contect of a file
TallyNotFound
The tally <mesh_id> could not be found in a file
PointNotFound
Unable to find a point within the mesh
EmptyCollection
Empty collection: i.e. vector, array, slice, etc… of len()==0
IndexOutOfBounds
Index outside an acceptable index range
UnexpectedLength
Collection length does not match the expectation
UnexpectedNumberOfVoxels
The number of voxels in a Mesh does not match the expectation
FailedParse
Clearer parser errors with better context
Nom(String)
Raw nom crate errors